summaryrefslogtreecommitdiff
path: root/src/mongo/dbtests/query_stage_collscan.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/dbtests/query_stage_collscan.cpp')
-rw-r--r--src/mongo/dbtests/query_stage_collscan.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/mongo/dbtests/query_stage_collscan.cpp b/src/mongo/dbtests/query_stage_collscan.cpp
index f2e406e29fb..42bd6931bb5 100644
--- a/src/mongo/dbtests/query_stage_collscan.cpp
+++ b/src/mongo/dbtests/query_stage_collscan.cpp
@@ -103,7 +103,7 @@ namespace QueryStageCollectionScan {
void getLocs(Collection* collection,
CollectionScanParams::Direction direction,
- vector<DiskLoc>* out) {
+ vector<RecordId>* out) {
WorkingSet ws;
CollectionScanParams params;
@@ -261,8 +261,8 @@ namespace QueryStageCollectionScan {
Collection* coll = ctx.getCollection();
- // Get the DiskLocs that would be returned by an in-order scan.
- vector<DiskLoc> locs;
+ // Get the RecordIds that would be returned by an in-order scan.
+ vector<RecordId> locs;
getLocs(coll, CollectionScanParams::FORWARD, &locs);
// Configure the scan.
@@ -322,8 +322,8 @@ namespace QueryStageCollectionScan {
Client::WriteContext ctx(&_txn, ns());
Collection* coll = ctx.getCollection();
- // Get the DiskLocs that would be returned by an in-order scan.
- vector<DiskLoc> locs;
+ // Get the RecordIds that would be returned by an in-order scan.
+ vector<RecordId> locs;
getLocs(coll, CollectionScanParams::BACKWARD, &locs);
// Configure the scan.